@@ -34,7 +34,7 @@ import github.NamedUser
 
 class GistComment(github.GithubObject.CompletableGithubObject):
     """
-    This class represents GistComments. The reference can be found here https://developer.github.com/v3/gists/comments/
+    This class represents GistComments. The reference can be found here https://docs.github.com/en/rest/reference/gists#comments
     """
 
     def __repr__(self):
@@ -90,14 +90,14 @@ class GistComment(github.GithubObject.CompletableGithubObject):
 
     def delete(self):
         """
-        :calls: `DELETE /gists/:gist_id/comments/:id <http://developer.github.com/v3/gists/comments>`_
+        :calls: `DELETE /gists/{gist_id}/comments/{id} <https://docs.github.com/en/rest/reference/gists#comments>`_
         :rtype: None
         """
         headers, data = self._requester.requestJsonAndCheck("DELETE", self.url)
 
     def edit(self, body):
         """
-        :calls: `PATCH /gists/:gist_id/comments/:id <http://developer.github.com/v3/gists/comments>`_
+        :calls: `PATCH /gists/{gist_id}/comments/{id} <https://docs.github.com/en/rest/reference/gists#comments>`_
         :param body: string
         :rtype: None
         """
