@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 ############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
@@ -30,12 +28,10 @@
 #                                                                              #
 ################################################################################
 
-
 import github.GithubObject
-import six
 
 
-class InputGitAuthor(object):
+class InputGitAuthor:
     """
     This class represents InputGitAuthors
     """
@@ -47,16 +43,18 @@ class InputGitAuthor(object):
         :param date: string
         """
 
-        assert isinstance(name, (str, six.text_type)), name
-        assert isinstance(email, (str, six.text_type)), email
-        assert date is github.GithubObject.NotSet or isinstance(date, (str, six.text_type)), date  # @todo Datetime?
+        assert isinstance(name, str), name
+        assert isinstance(email, str), email
+        assert date is github.GithubObject.NotSet or isinstance(
+            date, str
+        ), date  # @todo Datetime?
 
         self.__name = name
         self.__email = email
         self.__date = date
 
     def __repr__(self):
-        return 'InputGitAuthor(name="{}")'.format(self.__name)
+        return f'InputGitAuthor(name="{self.__name}")'
 
     @property
     def _identity(self):
