@@ -50,7 +50,6 @@
 import datetime
 import pickle
 import time
-import warnings
 
 import jwt
 import requests
@@ -100,24 +99,22 @@ class Github:
         jwt=None,
         base_url=DEFAULT_BASE_URL,
         timeout=DEFAULT_TIMEOUT,
-        client_id=None,
-        client_secret=None,
         user_agent="PyGithub/Python",
         per_page=DEFAULT_PER_PAGE,
         verify=True,
         retry=None,
+        pool_size=None,
     ):
         """
         :param login_or_token: string
         :param password: string
         :param base_url: string
         :param timeout: integer
-        :param client_id: string
-        :param client_secret: string
         :param user_agent: string
         :param per_page: int
         :param verify: boolean or string
         :param retry: int or urllib3.util.retry.Retry object
+        :param pool_size: int
         """
 
         assert login_or_token is None or isinstance(login_or_token, str), login_or_token
@@ -125,59 +122,49 @@ class Github:
         assert jwt is None or isinstance(jwt, str), jwt
         assert isinstance(base_url, str), base_url
         assert isinstance(timeout, int), timeout
-        assert client_id is None or isinstance(client_id, str), client_id
-        assert client_secret is None or isinstance(client_secret, str), client_secret
         assert user_agent is None or isinstance(user_agent, str), user_agent
         assert (
             retry is None
             or isinstance(retry, (int))
             or isinstance(retry, (urllib3.util.Retry))
         )
-        if client_id is not None or client_secret is not None:
-            warnings.warn(
-                "client_id and client_secret are deprecated and will be removed in a future release, switch to token authentication",
-                FutureWarning,
-                stacklevel=2,
-            )
+        assert pool_size is None or isinstance(pool_size, (int)), pool_size
         self.__requester = Requester(
             login_or_token,
             password,
             jwt,
             base_url,
             timeout,
-            client_id,
-            client_secret,
             user_agent,
             per_page,
             verify,
             retry,
+            pool_size,
         )
 
-    def __get_FIX_REPO_GET_GIT_REF(self):
+    @property
+    def FIX_REPO_GET_GIT_REF(self):
         """
         :type: bool
         """
         return self.__requester.FIX_REPO_GET_GIT_REF
 
-    def __set_FIX_REPO_GET_GIT_REF(self, value):
+    @FIX_REPO_GET_GIT_REF.setter
+    def FIX_REPO_GET_GIT_REF(self, value):
         self.__requester.FIX_REPO_GET_GIT_REF = value
 
-    FIX_REPO_GET_GIT_REF = property(
-        __get_FIX_REPO_GET_GIT_REF, __set_FIX_REPO_GET_GIT_REF
-    )
-
-    def __get_per_page(self):
+    # v2: Remove this property? Why should it be necessary to read/modify it after construction
+    @property
+    def per_page(self):
         """
         :type: int
         """
         return self.__requester.per_page
 
-    def __set_per_page(self, value):
+    @per_page.setter
+    def per_page(self, value):
         self.__requester.per_page = value
 
-    # v2: Remove this property? Why should it be necessary to read/modify it after construction
-    per_page = property(__get_per_page, __set_per_page)
-
     # v2: Provide a unified way to access values of headers of last response
     # v2: (and add/keep ad hoc properties for specific useful headers like rate limiting, oauth scopes, etc.)
     # v2: Return an instance of a class: using a tuple did not allow to add a field "resettime"
@@ -208,7 +195,7 @@ class Github:
         """
         Rate limit status for different resources (core/search/graphql).
 
-        :calls: `GET /rate_limit <http://developer.github.com/v3/rate_limit>`_
+        :calls: `GET /rate_limit <https://docs.github.com/en/rest/reference/rate-limit>`_
         :rtype: :class:`github.RateLimit.RateLimit`
         """
         headers, data = self.__requester.requestJsonAndCheck("GET", "/rate_limit")
@@ -223,18 +210,18 @@ class Github:
 
     def get_license(self, key=github.GithubObject.NotSet):
         """
-        :calls: `GET /license/:license <https://developer.github.com/v3/licenses/#get-an-individual-license>`_
+        :calls: `GET /license/{license} <https://docs.github.com/en/rest/reference/licenses#get-a-license>`_
         :param key: string
         :rtype: :class:`github.License.License`
         """
 
         assert isinstance(key, str), key
-        headers, data = self.__requester.requestJsonAndCheck("GET", "/licenses/" + key)
+        headers, data = self.__requester.requestJsonAndCheck("GET", f"/licenses/{key}")
         return github.License.License(self.__requester, headers, data, completed=True)
 
     def get_licenses(self):
         """
-        :calls: `GET /licenses <https://developer.github.com/v3/licenses/#list-all-licenses>`_
+        :calls: `GET /licenses <https://docs.github.com/en/rest/reference/licenses#get-all-commonly-used-licenses>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.License.License`
         """
 
@@ -246,7 +233,7 @@ class Github:
 
     def get_events(self):
         """
-        :calls: `GET /events <https://developer.github.com/v3/activity/events/#list-public-events>`_
+        :calls: `GET /events <https://docs.github.com/en/rest/reference/activity#list-public-events>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Event.Event`
         """
 
@@ -256,7 +243,7 @@ class Github:
 
     def get_user(self, login=github.GithubObject.NotSet):
         """
-        :calls: `GET /users/:user <http://developer.github.com/v3/users>`_ or `GET /user <http://developer.github.com/v3/users>`_
+        :calls: `GET /users/{user} <https://docs.github.com/en/rest/reference/users>`_ or `GET /user <https://docs.github.com/en/rest/reference/users>`_
         :param login: string
         :rtype: :class:`github.NamedUser.NamedUser` or :class:`github.AuthenticatedUser.AuthenticatedUser`
         """
@@ -267,7 +254,7 @@ class Github:
             )
         else:
             headers, data = self.__requester.requestJsonAndCheck(
-                "GET", "/users/" + login
+                "GET", f"/users/{login}"
             )
             return github.NamedUser.NamedUser(
                 self.__requester, headers, data, completed=True
@@ -275,21 +262,19 @@ class Github:
 
     def get_user_by_id(self, user_id):
         """
-        :calls: `GET /user/:id <http://developer.github.com/v3/users>`_
+        :calls: `GET /user/{id} <https://docs.github.com/en/rest/reference/users>`_
         :param user_id: int
         :rtype: :class:`github.NamedUser.NamedUser`
         """
         assert isinstance(user_id, int), user_id
-        headers, data = self.__requester.requestJsonAndCheck(
-            "GET", "/user/" + str(user_id)
-        )
+        headers, data = self.__requester.requestJsonAndCheck("GET", f"/user/{user_id}")
         return github.NamedUser.NamedUser(
             self.__requester, headers, data, completed=True
         )
 
     def get_users(self, since=github.GithubObject.NotSet):
         """
-        :calls: `GET /users <http://developer.github.com/v3/users>`_
+        :calls: `GET /users <https://docs.github.com/en/rest/reference/users>`_
         :param since: integer
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
         """
@@ -303,19 +288,19 @@ class Github:
 
     def get_organization(self, login):
         """
-        :calls: `GET /orgs/:org <http://developer.github.com/v3/orgs>`_
+        :calls: `GET /orgs/{org} <https://docs.github.com/en/rest/reference/orgs>`_
         :param login: string
         :rtype: :class:`github.Organization.Organization`
         """
         assert isinstance(login, str), login
-        headers, data = self.__requester.requestJsonAndCheck("GET", "/orgs/" + login)
+        headers, data = self.__requester.requestJsonAndCheck("GET", f"/orgs/{login}")
         return github.Organization.Organization(
             self.__requester, headers, data, completed=True
         )
 
     def get_organizations(self, since=github.GithubObject.NotSet):
         """
-        :calls: `GET /organizations <http://developer.github.com/v3/orgs#list-all-organizations>`_
+        :calls: `GET /organizations <https://docs.github.com/en/rest/reference/orgs#list-organizations>`_
         :param since: integer
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Organization.Organization`
         """
@@ -332,7 +317,7 @@ class Github:
 
     def get_repo(self, full_name_or_id, lazy=False):
         """
-        :calls: `GET /repos/:owner/:repo <http://developer.github.com/v3/repos>`_ or `GET /repositories/:id <http://developer.github.com/v3/repos>`_
+        :calls: `GET /repos/{owner}/{repo} <https://docs.github.com/en/rest/reference/repos>`_ or `GET /repositories/{id} <https://docs.github.com/en/rest/reference/repos>`_
         :rtype: :class:`github.Repository.Repository`
         """
         assert isinstance(full_name_or_id, (str, int)), full_name_or_id
@@ -342,16 +327,14 @@ class Github:
             return Repository.Repository(
                 self.__requester, {}, {"url": url}, completed=False
             )
-        headers, data = self.__requester.requestJsonAndCheck(
-            "GET", f"{url_base}{full_name_or_id}"
-        )
+        headers, data = self.__requester.requestJsonAndCheck("GET", url)
         return Repository.Repository(self.__requester, headers, data, completed=True)
 
     def get_repos(
         self, since=github.GithubObject.NotSet, visibility=github.GithubObject.NotSet
     ):
         """
-        :calls: `GET /repositories <http://developer.github.com/v3/repos/#list-all-public-repositories>`_
+        :calls: `GET /repositories <https://docs.github.com/en/rest/reference/repos#list-public-repositories>`_
         :param since: integer
         :param visibility: string ('all','public')
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Repository.Repository`
@@ -372,7 +355,7 @@ class Github:
 
     def get_project(self, id):
         """
-        :calls: `GET /projects/:project_id <https://developer.github.com/v3/projects/#get-a-project>`_
+        :calls: `GET /projects/{project_id} <https://docs.github.com/en/rest/reference/projects#get-a-project>`_
         :rtype: :class:`github.Project.Project`
         :param id: integer
         """
@@ -385,7 +368,7 @@ class Github:
 
     def get_project_column(self, id):
         """
-        :calls: `GET /projects/columns/:column_id <https://developer.github.com/v3/projects/columns/#get-a-project-column>`_
+        :calls: `GET /projects/columns/{column_id} <https://docs.github.com/en/rest/reference/projects#get-a-project-column>`_
         :rtype: :class:`github.ProjectColumn.ProjectColumn`
         :param id: integer
         """
@@ -400,17 +383,17 @@ class Github:
 
     def get_gist(self, id):
         """
-        :calls: `GET /gists/:id <http://developer.github.com/v3/gists>`_
+        :calls: `GET /gists/{id} <https://docs.github.com/en/rest/reference/gists>`_
         :param id: string
         :rtype: :class:`github.Gist.Gist`
         """
         assert isinstance(id, str), id
-        headers, data = self.__requester.requestJsonAndCheck("GET", "/gists/" + id)
+        headers, data = self.__requester.requestJsonAndCheck("GET", f"/gists/{id}")
         return github.Gist.Gist(self.__requester, headers, data, completed=True)
 
     def get_gists(self, since=github.GithubObject.NotSet):
         """
-        :calls: `GET /gists/public <http://developer.github.com/v3/gists>`_
+        :calls: `GET /gists/public <https://docs.github.com/en/rest/reference/gists>`_
         :param since: datetime.datetime format YYYY-MM-DDTHH:MM:SSZ
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Gist.Gist`
         """
@@ -432,7 +415,7 @@ class Github:
         **qualifiers,
     ):
         """
-        :calls: `GET /search/repositories <http://developer.github.com/v3/search>`_
+        :calls: `GET /search/repositories <https://docs.github.com/en/rest/reference/search>`_
         :param query: string
         :param sort: string ('stars', 'forks', 'updated')
         :param order: string ('asc', 'desc')
@@ -477,7 +460,7 @@ class Github:
         **qualifiers,
     ):
         """
-        :calls: `GET /search/users <http://developer.github.com/v3/search>`_
+        :calls: `GET /search/users <https://docs.github.com/en/rest/reference/search>`_
         :param query: string
         :param sort: string ('followers', 'repositories', 'joined')
         :param order: string ('asc', 'desc')
@@ -518,7 +501,7 @@ class Github:
         **qualifiers,
     ):
         """
-        :calls: `GET /search/issues <http://developer.github.com/v3/search>`_
+        :calls: `GET /search/issues <https://docs.github.com/en/rest/reference/search>`_
         :param query: string
         :param sort: string ('comments', 'created', 'updated')
         :param order: string ('asc', 'desc')
@@ -557,7 +540,7 @@ class Github:
         **qualifiers,
     ):
         """
-        :calls: `GET /search/code <http://developer.github.com/v3/search>`_
+        :calls: `GET /search/code <https://docs.github.com/en/rest/reference/search>`_
         :param query: string
         :param sort: string ('indexed')
         :param order: string ('asc', 'desc')
@@ -606,7 +589,7 @@ class Github:
         **qualifiers,
     ):
         """
-        :calls: `GET /search/commits <http://developer.github.com/v3/search>`_
+        :calls: `GET /search/commits <https://docs.github.com/en/rest/reference/search>`_
         :param query: string
         :param sort: string ('author-date', 'committer-date')
         :param order: string ('asc', 'desc')
@@ -615,19 +598,15 @@ class Github:
         """
         assert isinstance(query, str), query
         url_parameters = dict()
-        if (
-            sort is not github.GithubObject.NotSet
-        ):  # pragma no branch (Should be covered)
+        if sort is not github.GithubObject.NotSet:
             assert sort in ("author-date", "committer-date"), sort
             url_parameters["sort"] = sort
-        if (
-            order is not github.GithubObject.NotSet
-        ):  # pragma no branch (Should be covered)
+        if order is not github.GithubObject.NotSet:
             assert order in ("asc", "desc"), order
             url_parameters["order"] = order
 
         query_chunks = []
-        if query:  # pragma no branch (Should be covered)
+        if query:
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
@@ -646,7 +625,7 @@ class Github:
 
     def search_topics(self, query, **qualifiers):
         """
-        :calls: `GET /search/topics <http://developer.github.com/v3/search>`_
+        :calls: `GET /search/topics <https://docs.github.com/en/rest/reference/search>`_
         :param query: string
         :param qualifiers: keyword dict query qualifiers
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Topic.Topic`
@@ -674,7 +653,7 @@ class Github:
 
     def render_markdown(self, text, context=github.GithubObject.NotSet):
         """
-        :calls: `POST /markdown <http://developer.github.com/v3/markdown>`_
+        :calls: `POST /markdown <https://docs.github.com/en/rest/reference/markdown>`_
         :param text: string
         :param context: :class:`github.Repository.Repository`
         :rtype: string
@@ -694,13 +673,13 @@ class Github:
 
     def get_hook(self, name):
         """
-        :calls: `GET /hooks/:name <http://developer.github.com/v3/repos/hooks/>`_
+        :calls: `GET /hooks/{name} <https://docs.github.com/en/rest/reference/repos#webhooks>`_
         :param name: string
         :rtype: :class:`github.HookDescription.HookDescription`
         """
         assert isinstance(name, str), name
         headers, attributes = self.__requester.requestJsonAndCheck(
-            "GET", "/hooks/" + name
+            "GET", f"/hooks/{name}"
         )
         return HookDescription.HookDescription(
             self.__requester, headers, attributes, completed=True
@@ -708,7 +687,7 @@ class Github:
 
     def get_hooks(self):
         """
-        :calls: `GET /hooks <http://developer.github.com/v3/repos/hooks/>`_
+        :calls: `GET /hooks <https://docs.github.com/en/rest/reference/repos#webhooks>`_
         :rtype: list of :class:`github.HookDescription.HookDescription`
         """
         headers, data = self.__requester.requestJsonAndCheck("GET", "/hooks")
@@ -721,7 +700,7 @@ class Github:
 
     def get_gitignore_templates(self):
         """
-        :calls: `GET /gitignore/templates <http://developer.github.com/v3/gitignore>`_
+        :calls: `GET /gitignore/templates <https://docs.github.com/en/rest/reference/gitignore>`_
         :rtype: list of string
         """
         headers, data = self.__requester.requestJsonAndCheck(
@@ -731,12 +710,12 @@ class Github:
 
     def get_gitignore_template(self, name):
         """
-        :calls: `GET /gitignore/templates/:name <http://developer.github.com/v3/gitignore>`_
+        :calls: `GET /gitignore/templates/{name} <https://docs.github.com/en/rest/reference/gitignore>`_
         :rtype: :class:`github.GitignoreTemplate.GitignoreTemplate`
         """
         assert isinstance(name, str), name
         headers, attributes = self.__requester.requestJsonAndCheck(
-            "GET", "/gitignore/templates/" + name
+            "GET", f"/gitignore/templates/{name}"
         )
         return GitignoreTemplate.GitignoreTemplate(
             self.__requester, headers, attributes, completed=True
@@ -744,7 +723,7 @@ class Github:
 
     def get_emojis(self):
         """
-        :calls: `GET /emojis <http://developer.github.com/v3/emojis/>`_
+        :calls: `GET /emojis <https://docs.github.com/en/rest/reference/emojis>`_
         :rtype: dictionary of type => url for emoji`
         """
         headers, attributes = self.__requester.requestJsonAndCheck("GET", "/emojis")
@@ -770,7 +749,7 @@ class Github:
 
         :param obj: the object to pickle
         :param file: the file-like object to pickle to
-        :param protocol: the `pickling protocol <http://docs.python.org/2.7/library/pickle.html#data-stream-format>`_
+        :param protocol: the `pickling protocol <https://python.readthedocs.io/en/latest/library/pickle.html#data-stream-format>`_
         """
         pickle.dump((obj.__class__, obj.raw_data, obj.raw_headers), file, protocol)
 
@@ -793,7 +772,7 @@ class Github:
 
     def get_app(self, slug=github.GithubObject.NotSet):
         """
-        :calls: `GET /apps/:slug <https://docs.github.com/en/rest/reference/apps>`_ or `GET /app <https://docs.github.com/en/rest/reference/apps>`_
+        :calls: `GET /apps/{slug} <https://docs.github.com/en/rest/reference/apps>`_ or `GET /app <https://docs.github.com/en/rest/reference/apps>`_
         :param slug: string
         :rtype: :class:`github.GithubApp.GithubApp`
         """
@@ -803,7 +782,7 @@ class Github:
                 self.__requester, {}, {"url": "/app"}, completed=False
             )
         else:
-            headers, data = self.__requester.requestJsonAndCheck("GET", "/apps/" + slug)
+            headers, data = self.__requester.requestJsonAndCheck("GET", f"/apps/{slug}")
             return GithubApp.GithubApp(self.__requester, headers, data, completed=True)
 
 
@@ -852,9 +831,7 @@ class GithubIntegration:
         if user_id:
             body = {"user_id": user_id}
         response = requests.post(
-            "{}/app/installations/{}/access_tokens".format(
-                self.base_url, installation_id
-            ),
+            f"{self.base_url}/app/installations/{installation_id}/access_tokens",
             headers={
                 "Authorization": f"Bearer {self.create_jwt()}",
                 "Accept": Consts.mediaTypeIntegrationPreview,
@@ -884,7 +861,7 @@ class GithubIntegration:
 
     def get_installation(self, owner, repo):
         """
-        :calls: `GET /repos/:owner/:repo/installation <https://developer.github.com/v3/apps/#get-a-repository-installation>`_
+        :calls: `GET /repos/{owner}/{repo}/installation <https://docs.github.com/en/rest/reference/apps#get-a-repository-installation-for-the-authenticated-app>`_
         :param owner: str
         :param repo: str
         :rtype: :class:`github.Installation.Installation`
