@@ -59,7 +59,7 @@ from . import Consts
 
 class PullRequest(github.GithubObject.CompletableGithubObject):
     """
-    This class represents PullRequests. The reference can be found here http://developer.github.com/v3/pulls/
+    This class represents PullRequests. The reference can be found here https://docs.github.com/en/rest/reference/pulls
     """
 
     def __repr__(self):
@@ -381,7 +381,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def as_issue(self):
         """
-        :calls: `GET /repos/:owner/:repo/issues/:number <http://developer.github.com/v3/issues>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/{number} <https://docs.github.com/en/rest/reference/issues>`_
         :rtype: :class:`github.Issue.Issue`
         """
         headers, data = self._requester.requestJsonAndCheck("GET", self.issue_url)
@@ -389,7 +389,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def create_comment(self, body, commit_id, path, position):
         """
-        :calls: `POST /repos/:owner/:repo/pulls/:number/comments <http://developer.github.com/v3/pulls/comments>`_
+        :calls: `POST /repos/{owner}/{repo}/pulls/{number}/comments <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         :param body: string
         :param commit_id: :class:`github.Commit.Commit`
         :param path: string
@@ -400,7 +400,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def create_review_comment(self, body, commit_id, path, position):
         """
-        :calls: `POST /repos/:owner/:repo/pulls/:number/comments <http://developer.github.com/v3/pulls/comments>`_
+        :calls: `POST /repos/{owner}/{repo}/pulls/{number}/comments <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         :param body: string
         :param commit_id: :class:`github.Commit.Commit`
         :param path: string
@@ -418,7 +418,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             "position": position,
         }
         headers, data = self._requester.requestJsonAndCheck(
-            "POST", self.url + "/comments", input=post_parameters
+            "POST", f"{self.url}/comments", input=post_parameters
         )
         return github.PullRequestComment.PullRequestComment(
             self._requester, headers, data, completed=True
@@ -426,7 +426,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def create_review_comment_reply(self, comment_id, body):
         """
-        :calls: `POST /repos/:owner/:repo/pulls/:pull_number/comments/:comment_id/replies <http://developer.github.com/v3/pulls/comments>`_
+        :calls: `POST /repos/{owner}/{repo}/pulls/{pull_number}/comments/{comment_id}/replies <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         :param comment_id: int
         :param body: string
         :rtype: :class:`github.PullRequestComment.PullRequestComment`
@@ -436,7 +436,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         post_parameters = {"body": body}
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
-            self.url + "/comments/" + str(comment_id) + "/replies",
+            f"{self.url}/comments/{comment_id}/replies",
             input=post_parameters,
         )
         return github.PullRequestComment.PullRequestComment(
@@ -445,7 +445,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def create_issue_comment(self, body):
         """
-        :calls: `POST /repos/:owner/:repo/issues/:number/comments <http://developer.github.com/v3/issues/comments>`_
+        :calls: `POST /repos/{owner}/{repo}/issues/{number}/comments <https://docs.github.com/en/rest/reference/issues#comments>`_
         :param body: string
         :rtype: :class:`github.IssueComment.IssueComment`
         """
@@ -454,7 +454,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             "body": body,
         }
         headers, data = self._requester.requestJsonAndCheck(
-            "POST", self.issue_url + "/comments", input=post_parameters
+            "POST", f"{self.issue_url}/comments", input=post_parameters
         )
         return github.IssueComment.IssueComment(
             self._requester, headers, data, completed=True
@@ -468,7 +468,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         comments=github.GithubObject.NotSet,
     ):
         """
-        :calls: `POST /repos/:owner/:repo/pulls/:number/reviews <https://developer.github.com/v3/pulls/reviews/>`_
+        :calls: `POST /repos/{owner}/{repo}/pulls/{number}/reviews <https://docs.github.com/en/rest/reference/pulls#reviews>`_
         :param commit: github.Commit.Commit
         :param body: string
         :param event: string
@@ -496,7 +496,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         else:
             post_parameters["comments"] = comments
         headers, data = self._requester.requestJsonAndCheck(
-            "POST", self.url + "/reviews", input=post_parameters
+            "POST", f"{self.url}/reviews", input=post_parameters
         )
         return github.PullRequestReview.PullRequestReview(
             self._requester, headers, data, completed=True
@@ -508,7 +508,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         team_reviewers=github.GithubObject.NotSet,
     ):
         """
-        :calls: `POST /repos/:owner/:repo/pulls/:number/requested_reviewers <https://developer.github.com/v3/pulls/review_requests/>`_
+        :calls: `POST /repos/{owner}/{repo}/pulls/{number}/requested_reviewers <https://docs.github.com/en/rest/reference/pulls#review-requests>`_
         :param reviewers: list of strings
         :param team_reviewers: list of strings
         :rtype: None
@@ -523,7 +523,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             ), team_reviewers
             post_parameters["team_reviewers"] = team_reviewers
         headers, data = self._requester.requestJsonAndCheck(
-            "POST", self.url + "/requested_reviewers", input=post_parameters
+            "POST", f"{self.url}/requested_reviewers", input=post_parameters
         )
 
     def delete_review_request(
@@ -532,7 +532,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         team_reviewers=github.GithubObject.NotSet,
     ):
         """
-        :calls: `DELETE /repos/:owner/:repo/pulls/:number/requested_reviewers <https://developer.github.com/v3/pulls/review_requests/>`_
+        :calls: `DELETE /repos/{owner}/{repo}/pulls/{number}/requested_reviewers <https://docs.github.com/en/rest/reference/pulls#review-requests>`_
         :param reviewers: list of strings
         :param team_reviewers: list of strings
         :rtype: None
@@ -547,7 +547,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             ), team_reviewers
             post_parameters["team_reviewers"] = team_reviewers
         headers, data = self._requester.requestJsonAndCheck(
-            "DELETE", self.url + "/requested_reviewers", input=post_parameters
+            "DELETE", f"{self.url}/requested_reviewers", input=post_parameters
         )
 
     def edit(
@@ -559,7 +559,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         maintainer_can_modify=github.GithubObject.NotSet,
     ):
         """
-        :calls: `PATCH /repos/:owner/:repo/pulls/:number <http://developer.github.com/v3/pulls>`_
+        :calls: `PATCH /repos/{owner}/{repo}/pulls/{number} <https://docs.github.com/en/rest/reference/pulls>`_
         :param title: string
         :param body: string
         :param state: string
@@ -592,7 +592,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def get_comment(self, id):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/comments/:number <http://developer.github.com/v3/pulls/comments>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/comments/{number} <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         :param id: integer
         :rtype: :class:`github.PullRequestComment.PullRequestComment`
         """
@@ -600,13 +600,13 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def get_review_comment(self, id):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/comments/:number <http://developer.github.com/v3/pulls/comments>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/comments/{number} <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         :param id: integer
         :rtype: :class:`github.PullRequestComment.PullRequestComment`
         """
         assert isinstance(id, int), id
         headers, data = self._requester.requestJsonAndCheck(
-            "GET", self._parentUrl(self.url) + "/comments/" + str(id)
+            "GET", f"{self._parentUrl(self.url)}/comments/{id}"
         )
         return github.PullRequestComment.PullRequestComment(
             self._requester, headers, data, completed=True
@@ -616,14 +616,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         """
         Warning: this only returns review comments. For normal conversation comments, use get_issue_comments.
 
-        :calls: `GET /repos/:owner/:repo/pulls/:number/comments <http://developer.github.com/v3/pulls/comments>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number}/comments <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.PullRequestComment.PullRequestComment`
         """
         return self.get_review_comments()
 
     def get_review_comments(self, since=github.GithubObject.NotSet):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/:number/comments <http://developer.github.com/v3/pulls/comments>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number}/comments <https://docs.github.com/en/rest/reference/pulls#review-comments>`_
         :param since: datetime.datetime format YYYY-MM-DDTHH:MM:SSZ
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.PullRequestComment.PullRequestComment`
         """
@@ -636,13 +636,13 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         return github.PaginatedList.PaginatedList(
             github.PullRequestComment.PullRequestComment,
             self._requester,
-            self.url + "/comments",
+            f"{self.url}/comments",
             url_parameters,
         )
 
     def get_single_review_comments(self, id):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/:number/review/:id/comments <https://developer.github.com/v3/pulls/reviews/>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number}/review/{id}/comments <https://docs.github.com/en/rest/reference/pulls#reviews>`_
         :param id: integer
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.PullRequestComment.PullRequestComment`
         """
@@ -650,37 +650,37 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         return github.PaginatedList.PaginatedList(
             github.PullRequestComment.PullRequestComment,
             self._requester,
-            self.url + "/reviews/" + str(id) + "/comments",
+            f"{self.url}/reviews/{id}/comments",
             None,
         )
 
     def get_commits(self):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/:number/commits <http://developer.github.com/v3/pulls>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number}/commits <https://docs.github.com/en/rest/reference/pulls>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Commit.Commit`
         """
         return github.PaginatedList.PaginatedList(
-            github.Commit.Commit, self._requester, self.url + "/commits", None
+            github.Commit.Commit, self._requester, f"{self.url}/commits", None
         )
 
     def get_files(self):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/:number/files <http://developer.github.com/v3/pulls>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number}/files <https://docs.github.com/en/rest/reference/pulls>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.File.File`
         """
         return github.PaginatedList.PaginatedList(
-            github.File.File, self._requester, self.url + "/files", None
+            github.File.File, self._requester, f"{self.url}/files", None
         )
 
     def get_issue_comment(self, id):
         """
-        :calls: `GET /repos/:owner/:repo/issues/comments/:id <http://developer.github.com/v3/issues/comments>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/comments/{id} <https://docs.github.com/en/rest/reference/issues#comments>`_
         :param id: integer
         :rtype: :class:`github.IssueComment.IssueComment`
         """
         assert isinstance(id, int), id
         headers, data = self._requester.requestJsonAndCheck(
-            "GET", self._parentUrl(self.issue_url) + "/comments/" + str(id)
+            "GET", f"{self._parentUrl(self.issue_url)}/comments/{id}"
         )
         return github.IssueComment.IssueComment(
             self._requester, headers, data, completed=True
@@ -688,39 +688,39 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def get_issue_comments(self):
         """
-        :calls: `GET /repos/:owner/:repo/issues/:number/comments <http://developer.github.com/v3/issues/comments>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/{number}/comments <https://docs.github.com/en/rest/reference/issues#comments>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.IssueComment.IssueComment`
         """
         return github.PaginatedList.PaginatedList(
             github.IssueComment.IssueComment,
             self._requester,
-            self.issue_url + "/comments",
+            f"{self.issue_url}/comments",
             None,
         )
 
     def get_issue_events(self):
         """
-        :calls: `GET /repos/:owner/:repo/issues/:issue_number/events <http://developer.github.com/v3/issues/events>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/{issue_number}/events <https://docs.github.com/en/rest/reference/issues#events>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.IssueEvent.IssueEvent`
         """
         return github.PaginatedList.PaginatedList(
             github.IssueEvent.IssueEvent,
             self._requester,
-            self.issue_url + "/events",
+            f"{self.issue_url}/events",
             None,
             headers={"Accept": Consts.mediaTypeLockReasonPreview},
         )
 
     def get_review(self, id):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/:number/reviews/:id <https://developer.github.com/v3/pulls/reviews>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number}/reviews/{id} <https://docs.github.com/en/rest/reference/pulls#reviews>`_
         :param id: integer
         :rtype: :class:`github.PullRequestReview.PullRequestReview`
         """
         assert isinstance(id, int), id
         headers, data = self._requester.requestJsonAndCheck(
             "GET",
-            self.url + "/reviews/" + str(id),
+            f"{self.url}/reviews/{id}",
         )
         return github.PullRequestReview.PullRequestReview(
             self._requester, headers, data, completed=True
@@ -728,33 +728,33 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def get_reviews(self):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/:number/reviews <https://developer.github.com/v3/pulls/reviews/>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number}/reviews <https://docs.github.com/en/rest/reference/pulls#reviews>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.PullRequestReview.PullRequestReview`
         """
         return github.PaginatedList.PaginatedList(
             github.PullRequestReview.PullRequestReview,
             self._requester,
-            self.url + "/reviews",
+            f"{self.url}/reviews",
             None,
         )
 
     def get_review_requests(self):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/:number/requested_reviewers <https://developer.github.com/v3/pulls/review_requests/>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number}/requested_reviewers <https://docs.github.com/en/rest/reference/pulls#review-requests>`_
         :rtype: tuple of :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser` and of :class:`github.PaginatedList.PaginatedList` of :class:`github.Team.Team`
         """
         return (
             github.PaginatedList.PaginatedList(
                 github.NamedUser.NamedUser,
                 self._requester,
-                self.url + "/requested_reviewers",
+                f"{self.url}/requested_reviewers",
                 None,
                 list_item="users",
             ),
             github.PaginatedList.PaginatedList(
                 github.Team.Team,
                 self._requester,
-                self.url + "/requested_reviewers",
+                f"{self.url}/requested_reviewers",
                 None,
                 list_item="teams",
             ),
@@ -762,16 +762,16 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def get_labels(self):
         """
-        :calls: `GET /repos/:owner/:repo/issues/:number/labels <http://developer.github.com/v3/issues/labels>`_
+        :calls: `GET /repos/{owner}/{repo}/issues/{number}/labels <https://docs.github.com/en/rest/reference/issues#labels>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.Label.Label`
         """
         return github.PaginatedList.PaginatedList(
-            github.Label.Label, self._requester, self.issue_url + "/labels", None
+            github.Label.Label, self._requester, f"{self.issue_url}/labels", None
         )
 
     def add_to_labels(self, *labels):
         """
-        :calls: `POST /repos/:owner/:repo/issues/:number/labels <http://developer.github.com/v3/issues/labels>`_
+        :calls: `POST /repos/{owner}/{repo}/issues/{number}/labels <https://docs.github.com/en/rest/reference/issues#labels>`_
         :param label: :class:`github.Label.Label` or string
         :rtype: None
         """
@@ -783,21 +783,21 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             for label in labels
         ]
         headers, data = self._requester.requestJsonAndCheck(
-            "POST", self.issue_url + "/labels", input=post_parameters
+            "POST", f"{self.issue_url}/labels", input=post_parameters
         )
 
     def delete_labels(self):
         """
-        :calls: `DELETE /repos/:owner/:repo/issues/:number/labels <http://developer.github.com/v3/issues/labels>`_
+        :calls: `DELETE /repos/{owner}/{repo}/issues/{number}/labels <https://docs.github.com/en/rest/reference/issues#labels>`_
         :rtype: None
         """
         headers, data = self._requester.requestJsonAndCheck(
-            "DELETE", self.issue_url + "/labels"
+            "DELETE", f"{self.issue_url}/labels"
         )
 
     def remove_from_labels(self, label):
         """
-        :calls: `DELETE /repos/:owner/:repo/issues/:number/labels/:name <http://developer.github.com/v3/issues/labels>`_
+        :calls: `DELETE /repos/{owner}/{repo}/issues/{number}/labels/{name} <https://docs.github.com/en/rest/reference/issues#labels>`_
         :param label: :class:`github.Label.Label` or string
         :rtype: None
         """
@@ -807,12 +807,12 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         else:
             label = urllib.parse.quote(label)
         headers, data = self._requester.requestJsonAndCheck(
-            "DELETE", self.issue_url + "/labels/" + label
+            "DELETE", f"{self.issue_url}/labels/{label}"
         )
 
     def set_labels(self, *labels):
         """
-        :calls: `PUT /repos/:owner/:repo/issues/:number/labels <http://developer.github.com/v3/issues/labels>`_
+        :calls: `PUT /repos/{owner}/{repo}/issues/{number}/labels <https://docs.github.com/en/rest/reference/issues#labels>`_
         :param labels: list of :class:`github.Label.Label` or strings
         :rtype: None
         """
@@ -824,15 +824,15 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             for label in labels
         ]
         headers, data = self._requester.requestJsonAndCheck(
-            "PUT", self.issue_url + "/labels", input=post_parameters
+            "PUT", f"{self.issue_url}/labels", input=post_parameters
         )
 
     def is_merged(self):
         """
-        :calls: `GET /repos/:owner/:repo/pulls/:number/merge <http://developer.github.com/v3/pulls>`_
+        :calls: `GET /repos/{owner}/{repo}/pulls/{number}/merge <https://docs.github.com/en/rest/reference/pulls>`_
         :rtype: bool
         """
-        status, headers, data = self._requester.requestJson("GET", self.url + "/merge")
+        status, headers, data = self._requester.requestJson("GET", f"{self.url}/merge")
         return status == 204
 
     def merge(
@@ -843,7 +843,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         sha=github.GithubObject.NotSet,
     ):
         """
-        :calls: `PUT /repos/:owner/:repo/pulls/:number/merge <http://developer.github.com/v3/pulls>`_
+        :calls: `PUT /repos/{owner}/{repo}/pulls/{number}/merge <https://docs.github.com/en/rest/reference/pulls>`_
         :param commit_message: string
         :param commit_title: string
         :param merge_method: string
@@ -870,7 +870,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
         if sha is not github.GithubObject.NotSet:
             post_parameters["sha"] = sha
         headers, data = self._requester.requestJsonAndCheck(
-            "PUT", self.url + "/merge", input=post_parameters
+            "PUT", f"{self.url}/merge", input=post_parameters
         )
         return github.PullRequestMergeStatus.PullRequestMergeStatus(
             self._requester, headers, data, completed=True
@@ -878,7 +878,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
 
     def add_to_assignees(self, *assignees):
         """
-        :calls: `POST /repos/:owner/:repo/issues/:number/assignees <https://developer.github.com/v3/issues/assignees>`_
+        :calls: `POST /repos/{owner}/{repo}/issues/{number}/assignees <https://docs.github.com/en/rest/reference/issues#assignees>`_
         :param assignees: list of :class:`github.NamedUser.NamedUser` or string
         :rtype: None
         """
@@ -895,14 +895,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             ]
         }
         headers, data = self._requester.requestJsonAndCheck(
-            "POST", self.issue_url + "/assignees", input=post_parameters
+            "POST", f"{self.issue_url}/assignees", input=post_parameters
         )
         # Only use the assignees attribute, since we call this PR as an issue
         self._useAttributes({"assignees": data["assignees"]})
 
     def remove_from_assignees(self, *assignees):
         """
-        :calls: `DELETE /repos/:owner/:repo/issues/:number/assignees <https://developer.github.com/v3/issues/assignees>`_
+        :calls: `DELETE /repos/{owner}/{repo}/issues/{number}/assignees <https://docs.github.com/en/rest/reference/issues#assignees>`_
         :param assignees: list of :class:`github.NamedUser.NamedUser` or string
         :rtype: None
         """
@@ -919,14 +919,14 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             ]
         }
         headers, data = self._requester.requestJsonAndCheck(
-            "DELETE", self.issue_url + "/assignees", input=post_parameters
+            "DELETE", f"{self.issue_url}/assignees", input=post_parameters
         )
         # Only use the assignees attribute, since we call this PR as an issue
         self._useAttributes({"assignees": data["assignees"]})
 
     def update_branch(self, expected_head_sha=github.GithubObject.NotSet):
         """
-        :calls `PUT /repos/:owner/:repo/pulls/:pull_number/update-branch <https://developer.github.com/v3/pulls>`_
+        :calls `PUT /repos/{owner}/{repo}/pulls/{pull_number}/update-branch <https://docs.github.com/en/rest/reference/pulls>`_
         :param expected_head_sha: string
         :rtype: bool
         """
@@ -938,7 +938,7 @@ class PullRequest(github.GithubObject.CompletableGithubObject):
             post_parameters["expected_head_sha"] = expected_head_sha
         status, headers, data = self._requester.requestJson(
             "PUT",
-            self.url + "/update-branch",
+            f"{self.url}/update-branch",
             input=post_parameters,
             headers={"Accept": Consts.updateBranchPreview},
         )
